# snlp

[![HitCount](http://hits.dwyl.com/meghdadFar/snlp.svg)](http://hits.dwyl.com/meghdadFar/snlp)

Statistical NLP (SNLP): A practical package with statisical natural language processing tools. SNLP is based on statistical and distributional attributes of natural language and hence most of the functionalities are unsupervised.

# Features
- Identifying Multiword Expressions (Collocations) in the corpus. Used for terminology and keyphrase extraction. Can lead to improvement in text classification. 
- Identifying statistically redundant words for filtering. Usually leads to an improvement in document classification. 
## Upcoming Features
- Anamoly Detection. 
- Identifying non-compositional compouds: Can be used for tasks such as profanity/hate-speech detection, and linguistic analysis of a corpus.
# Usage

